@@ -1,6 +1,6 @@
 magmap<-
-function(data, lo=0, hi=1, flip=FALSE, range=c(0,2/3), type='quan', log=FALSE, bad=NA, clip=''){
-if(log){
+function(data, lo=0, hi=1, flip=FALSE, range=c(0,2/3), type='quan', stretch='lin', stretchscale=1, bad=NA, clip=''){
+if(stretch=='log'){
 	good=is.na(data)==FALSE & is.nan(data)==FALSE & is.infinite(data)==FALSE & is.null(data)==FALSE & data>0
 	}else{
 	good=is.na(data)==FALSE & is.nan(data)==FALSE & is.infinite(data)==FALSE & is.null(data)==FALSE
@@ -22,19 +22,22 @@ if(type=='rank'){
 	hi=length(data[good])
 	data[order(data[good])]=lo:hi
 }
-if(log & lo==0){stop('lo value is 0 and scale is step to log- this is not allowed!')}
-if(log & hi==0){stop('hi value is 0 and scale is step to log- this is not allowed!')}
+if(stretch=='log' & lo==0){stop('lo value is 0 and stretch=\'log\'- this is not allowed!')}
+if(stretch=='log' & hi==0){stop('hi value is 0 and stretch=\'log\'- this is not allowed!')}
+data=data*stretchscale
 if(lo>hi){stop('lo>hi is not allowed')}
 if(lo==hi){data=rep((range[2]+range[1])/2,length(data))}
 if(lo<hi){
-	if(log){data=suppressWarnings(log10(data));lo=log10(lo);hi=log10(hi)}
+	if(stretch=='log'){data=suppressWarnings(log10(data));lo=log10(lo);hi=log10(hi)}
+  if(stretch=='atan'){data=atan(data);lo=atan(lo);hi=atan(hi)}
+	if(stretch=='asinh'){data=asinh(data);lo=asinh(lo);hi=asinh(hi)}
   losel=data<lo; hisel=data>hi
 	data[losel]=lo; data[hisel]=hi
 	data=data-lo
 	data=range[1]+(data*(range[2]-range[1])/(hi-lo))
 	if(flip){data=range[2]-data+range[1]}
   if(clip=='NA'){data[losel]=NA;data[hisel]=NA}
-	if(log){lo=10^lo;hi=10^hi}
+	if(stretch=='log'){lo=10^lo;hi=10^hi}
 }
 data[! good]=bad
 return(list(map=data,datalim=c(lo,hi),maplim=range,loclip=length(which(data[good]==range[1]))/length(data[good]),hiclip=length(which(data[good]==range[2]))/length(data[good])))
